==> james-project-3.7.6-source-release.zip: james-project/mailet/standard/src/test/java/org/apache/james/transport/mailets/MappingArgumentTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.transport.mailets;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.assertThatThrownBy;

import javax.mail.MessagingException;

import org.assertj.core.data.MapEntry;
import org.junit.jupiter.api.Test;

class MappingArgumentTest {

    @Test
    void parseShouldFailIfCalledWithNull() {
        assertThatThrownBy(() -> MappingArgument.parse(null))
            .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldFailIfCalledWhenMissingMappingParts() {
        assertThatThrownBy(() -> MappingArgument.parse("key1;value1,key2"))
            .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldFailIfCalledWhenExtraMappingParts() {
        assertThatThrownBy(() -> MappingArgument.parse("key1;value1,key2;value1;value3"))
           .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldWorkForEmptyMapping() throws MessagingException {
        assertThat(MappingArgument.parse(""))
            .isEmpty();
    }

    @Test
    void parseShouldWorkForEmptyMappingWithSpace() throws MessagingException {
        assertThat(MappingArgument.parse("  "))
            .isEmpty();
    }

    @Test
    void parseShouldWorkForValidParsingWithOnlyOneKey() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }

    @Test
    void parseShouldWorkForValidParsingWithMoreThanOneKey() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,key2;value2"))
            .containsExactly(MapEntry.entry("key1", "value1"), MapEntry.entry("key2", "value2"));
    }

    @Test
    void parserShouldTrimSpacesAroundSemiColon() throws MessagingException {
        assertThat(MappingArgument.parse("key1;    value1"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }

    @Test
    void parserShouldTrimSpacesAroundComa() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,  key2;value2"))
            .containsExactly(MapEntry.entry("key1", "value1"), MapEntry.entry("key2", "value2"));
    }

    @Test
    void parserShouldNotFailWhenExtraComa() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }
}

==> james-project-3.9.0-source-release.zip: james-project/mailet/standard/src/test/java/org/apache/james/transport/mailets/MappingArgumentTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.transport.mailets;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.assertThatThrownBy;

import jakarta.mail.MessagingException;

import org.assertj.core.data.MapEntry;
import org.junit.jupiter.api.Test;

class MappingArgumentTest {

    @Test
    void parseShouldFailIfCalledWithNull() {
        assertThatThrownBy(() -> MappingArgument.parse(null))
            .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldFailIfCalledWhenMissingMappingParts() {
        assertThatThrownBy(() -> MappingArgument.parse("key1;value1,key2"))
            .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldFailIfCalledWhenExtraMappingParts() {
        assertThatThrownBy(() -> MappingArgument.parse("key1;value1,key2;value1;value3"))
           .isInstanceOf(IllegalArgumentException.class);
    }

    @Test
    void parseShouldWorkForEmptyMapping() throws MessagingException {
        assertThat(MappingArgument.parse(""))
            .isEmpty();
    }

    @Test
    void parseShouldWorkForEmptyMappingWithSpace() throws MessagingException {
        assertThat(MappingArgument.parse("  "))
            .isEmpty();
    }

    @Test
    void parseShouldWorkForValidParsingWithOnlyOneKey() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }

    @Test
    void parseShouldWorkForValidParsingWithMoreThanOneKey() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,key2;value2"))
            .containsExactly(MapEntry.entry("key1", "value1"), MapEntry.entry("key2", "value2"));
    }

    @Test
    void parserShouldTrimSpacesAroundSemiColon() throws MessagingException {
        assertThat(MappingArgument.parse("key1;    value1"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }

    @Test
    void parserShouldTrimSpacesAroundComa() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,  key2;value2"))
            .containsExactly(MapEntry.entry("key1", "value1"), MapEntry.entry("key2", "value2"));
    }

    @Test
    void parserShouldNotFailWhenExtraComa() throws MessagingException {
        assertThat(MappingArgument.parse("key1;value1,"))
            .containsExactly(MapEntry.entry("key1", "value1"));
    }
}
